import { PropType, SVGAttributes } from 'vue';
import { GlobalHasSlot, GlobalRenderSlot } from './ContextMenu.vue';
declare const _default: import("vue").DefineComponent<{
    /**
     * Is this menu disabled?
     */
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Is this menu hidden?
     */
    hidden: {
        type: BooleanConstructor;
        default: boolean;
    };
    customRender: {
        type: FunctionConstructor;
        default: null;
    };
    /**
     * Custom css class for submenu
     */
    customClass: {
        type: StringConstructor;
        default: string;
    };
    clickHandler: {
        type: PropType<() => void>;
        default: null;
    };
    /**
     * Menu label
     */
    label: {
        type: (ObjectConstructor | FunctionConstructor | StringConstructor)[];
        default: string;
    };
    /**
     * Menu icon (for icon class)
     */
    icon: {
        type: (ObjectConstructor | FunctionConstructor | StringConstructor)[];
        default: string;
    };
    /**
     * Custom icon library font class name.
     *
     * Only for css font icon, If you use the svg icon, you do not need to use this.
     */
    iconFontClass: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Is this menu item checked?
     *
     * The check mark are displayed on the left side of the icon, so it is not recommended to display the icon at the same time.
     */
    checked: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Shortcut key text display on the right.
     *
     * The shortcut keys here are only for display. You need to handle the key events by yourself.
     */
    shortcut: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Display icons use svg symbol (`<use xlink:href="#icon-symbol-name">`) ， only valid when icon attribute is empty.
     */
    svgIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * The user-defined attribute of the svg tag, which is valid when using `svgIcon`.
     */
    svgProps: {
        type: PropType<SVGAttributes>;
        default: null;
    };
    /**
     * Should a fixed-width icon area be reserved for menu items without icon. (this item)
     *
     * Default is true .
     *
     * The width of icon area can be override with css var `--mx-menu-placeholder-width`.
     */
    preserveIconWidth: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Show right arrow on this menu?
     */
    showRightArrow: {
        type: BooleanConstructor;
        default: boolean;
    };
    hasChildren: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Should close menu when Click this menu item ?
     */
    clickClose: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * When there are subitems in this item, is it allowed to trigger its own click event? Default is false
     */
    clickableWhenHasChildren: {
        type: BooleanConstructor;
        default: boolean;
    };
}, {
    getItemDataForChildren(): {
        disabled: boolean;
        label: string | Function | Record<string, any>;
        icon: string | Function | Record<string, any>;
        iconFontClass: string;
        showRightArrow: boolean;
        clickClose: boolean;
        clickableWhenHasChildren: boolean;
        shortcut: string;
        theme: string;
        isOpen: import("vue").Ref<boolean>;
        hasChildren: import("vue").Ref<boolean>;
        onClick: (e?: MouseEvent | undefined) => void;
        onMouseEnter: (e?: MouseEvent | undefined) => void;
    };
    showSubMenu: import("vue").Ref<boolean>;
    keyBoardFocusMenu: import("vue").Ref<boolean>;
    menuItemRef: import("vue").Ref<HTMLElement | undefined>;
    globalHasSlot: GlobalHasSlot;
    globalRenderSlot: GlobalRenderSlot;
    globalIconFontClass: string;
    onMouseEnter: (e?: MouseEvent | undefined) => void;
    onClick: (e?: MouseEvent | undefined) => void;
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, ("click" | "subMenuOpen" | "subMenuClose")[], "click" | "subMenuOpen" | "subMenuClose", import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<import("vue").ExtractPropTypes<{
    /**
     * Is this menu disabled?
     */
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Is this menu hidden?
     */
    hidden: {
        type: BooleanConstructor;
        default: boolean;
    };
    customRender: {
        type: FunctionConstructor;
        default: null;
    };
    /**
     * Custom css class for submenu
     */
    customClass: {
        type: StringConstructor;
        default: string;
    };
    clickHandler: {
        type: PropType<() => void>;
        default: null;
    };
    /**
     * Menu label
     */
    label: {
        type: (ObjectConstructor | FunctionConstructor | StringConstructor)[];
        default: string;
    };
    /**
     * Menu icon (for icon class)
     */
    icon: {
        type: (ObjectConstructor | FunctionConstructor | StringConstructor)[];
        default: string;
    };
    /**
     * Custom icon library font class name.
     *
     * Only for css font icon, If you use the svg icon, you do not need to use this.
     */
    iconFontClass: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Is this menu item checked?
     *
     * The check mark are displayed on the left side of the icon, so it is not recommended to display the icon at the same time.
     */
    checked: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Shortcut key text display on the right.
     *
     * The shortcut keys here are only for display. You need to handle the key events by yourself.
     */
    shortcut: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Display icons use svg symbol (`<use xlink:href="#icon-symbol-name">`) ， only valid when icon attribute is empty.
     */
    svgIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * The user-defined attribute of the svg tag, which is valid when using `svgIcon`.
     */
    svgProps: {
        type: PropType<SVGAttributes>;
        default: null;
    };
    /**
     * Should a fixed-width icon area be reserved for menu items without icon. (this item)
     *
     * Default is true .
     *
     * The width of icon area can be override with css var `--mx-menu-placeholder-width`.
     */
    preserveIconWidth: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Show right arrow on this menu?
     */
    showRightArrow: {
        type: BooleanConstructor;
        default: boolean;
    };
    hasChildren: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Should close menu when Click this menu item ?
     */
    clickClose: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * When there are subitems in this item, is it allowed to trigger its own click event? Default is false
     */
    clickableWhenHasChildren: {
        type: BooleanConstructor;
        default: boolean;
    };
}>> & {
    onClick?: ((...args: any[]) => any) | undefined;
    onSubMenuClose?: ((...args: any[]) => any) | undefined;
    onSubMenuOpen?: ((...args: any[]) => any) | undefined;
}, {
    customRender: Function;
    label: string | Function | Record<string, any>;
    icon: string | Function | Record<string, any>;
    iconFontClass: string;
    preserveIconWidth: boolean;
    svgIcon: string;
    svgProps: SVGAttributes;
    disabled: boolean;
    hidden: boolean;
    checked: boolean;
    shortcut: string;
    clickableWhenHasChildren: boolean;
    clickClose: boolean;
    customClass: string;
    clickHandler: () => void;
    showRightArrow: boolean;
    hasChildren: boolean;
}>;
/**
 * Menu Item
 */
export default _default;
